@@ -14,40 +14,29 @@ from asposewordscloud.models.requests.create_document_request import CreateDocum
 from asposewordscloud.models.requests.create_folder_request import CreateFolderRequest
 from asposewordscloud.models.requests.create_or_update_document_property_request import CreateOrUpdateDocumentPropertyRequest
 from asposewordscloud.models.requests.delete_all_paragraph_tab_stops_request import DeleteAllParagraphTabStopsRequest
-from asposewordscloud.models.requests.delete_all_paragraph_tab_stops_without_node_path_request import DeleteAllParagraphTabStopsWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_border_request import DeleteBorderRequest
 from asposewordscloud.models.requests.delete_borders_request import DeleteBordersRequest
 from asposewordscloud.models.requests.delete_comment_request import DeleteCommentRequest
 from asposewordscloud.models.requests.delete_document_property_request import DeleteDocumentPropertyRequest
 from asposewordscloud.models.requests.delete_drawing_object_request import DeleteDrawingObjectRequest
-from asposewordscloud.models.requests.delete_drawing_object_without_node_path_request import DeleteDrawingObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_field_request import DeleteFieldRequest
 from asposewordscloud.models.requests.delete_fields_request import DeleteFieldsRequest
-from asposewordscloud.models.requests.delete_fields_without_node_path_request import DeleteFieldsWithoutNodePathRequest
-from asposewordscloud.models.requests.delete_field_without_node_path_request import DeleteFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_file_request import DeleteFileRequest
 from asposewordscloud.models.requests.delete_folder_request import DeleteFolderRequest
 from asposewordscloud.models.requests.delete_footnote_request import DeleteFootnoteRequest
-from asposewordscloud.models.requests.delete_footnote_without_node_path_request import DeleteFootnoteWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_form_field_request import DeleteFormFieldRequest
-from asposewordscloud.models.requests.delete_form_field_without_node_path_request import DeleteFormFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_header_footer_request import DeleteHeaderFooterRequest
 from asposewordscloud.models.requests.delete_headers_footers_request import DeleteHeadersFootersRequest
 from asposewordscloud.models.requests.delete_macros_request import DeleteMacrosRequest
 from asposewordscloud.models.requests.delete_office_math_object_request import DeleteOfficeMathObjectRequest
-from asposewordscloud.models.requests.delete_office_math_object_without_node_path_request import DeleteOfficeMathObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_paragraph_request import DeleteParagraphRequest
 from asposewordscloud.models.requests.delete_paragraph_list_format_request import DeleteParagraphListFormatRequest
-from asposewordscloud.models.requests.delete_paragraph_list_format_without_node_path_request import DeleteParagraphListFormatWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_paragraph_tab_stop_request import DeleteParagraphTabStopRequest
-from asposewordscloud.models.requests.delete_paragraph_tab_stop_without_node_path_request import DeleteParagraphTabStopWithoutNodePathRequest
-from asposewordscloud.models.requests.delete_paragraph_without_node_path_request import DeleteParagraphWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_run_request import DeleteRunRequest
 from asposewordscloud.models.requests.delete_section_request import DeleteSectionRequest
 from asposewordscloud.models.requests.delete_table_request import DeleteTableRequest
 from asposewordscloud.models.requests.delete_table_cell_request import DeleteTableCellRequest
 from asposewordscloud.models.requests.delete_table_row_request import DeleteTableRowRequest
-from asposewordscloud.models.requests.delete_table_without_node_path_request import DeleteTableWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_watermark_request import DeleteWatermarkRequest
 from asposewordscloud.models.requests.download_file_request import DownloadFileRequest
 from asposewordscloud.models.requests.execute_mail_merge_request import ExecuteMailMergeRequest
@@ -61,13 +50,9 @@ from asposewordscloud.models.requests.get_comment_request import GetCommentReque
 from asposewordscloud.models.requests.get_comments_request import GetCommentsRequest
 from asposewordscloud.models.requests.get_document_request import GetDocumentRequest
 from asposewordscloud.models.requests.get_document_drawing_object_by_index_request import GetDocumentDrawingObjectByIndexRequest
-from asposewordscloud.models.requests.get_document_drawing_object_by_index_without_node_path_request import GetDocumentDrawingObjectByIndexWithoutNodePathRequest
 from asposewordscloud.models.requests.get_document_drawing_object_image_data_request import GetDocumentDrawingObjectImageDataRequest
-from asposewordscloud.models.requests.get_document_drawing_object_image_data_without_node_path_request import GetDocumentDrawingObjectImageDataWithoutNodePathRequest
 from asposewordscloud.models.requests.get_document_drawing_object_ole_data_request import GetDocumentDrawingObjectOleDataRequest
-from asposewordscloud.models.requests.get_document_drawing_object_ole_data_without_node_path_request import GetDocumentDrawingObjectOleDataWithoutNodePathRequest
 from asposewordscloud.models.requests.get_document_drawing_objects_request import GetDocumentDrawingObjectsRequest
-from asposewordscloud.models.requests.get_document_drawing_objects_without_node_path_request import GetDocumentDrawingObjectsWithoutNodePathRequest
 from asposewordscloud.models.requests.get_document_field_names_request import GetDocumentFieldNamesRequest
 from asposewordscloud.models.requests.get_document_field_names_online_request import GetDocumentFieldNamesOnlineRequest
 from asposewordscloud.models.requests.get_document_hyperlink_by_index_request import GetDocumentHyperlinkByIndexRequest
@@ -79,17 +64,11 @@ from asposewordscloud.models.requests.get_document_statistics_request import Get
 from asposewordscloud.models.requests.get_document_with_format_request import GetDocumentWithFormatRequest
 from asposewordscloud.models.requests.get_field_request import GetFieldRequest
 from asposewordscloud.models.requests.get_fields_request import GetFieldsRequest
-from asposewordscloud.models.requests.get_fields_without_node_path_request import GetFieldsWithoutNodePathRequest
-from asposewordscloud.models.requests.get_field_without_node_path_request import GetFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.get_files_list_request import GetFilesListRequest
 from asposewordscloud.models.requests.get_footnote_request import GetFootnoteRequest
 from asposewordscloud.models.requests.get_footnotes_request import GetFootnotesRequest
-from asposewordscloud.models.requests.get_footnotes_without_node_path_request import GetFootnotesWithoutNodePathRequest
-from asposewordscloud.models.requests.get_footnote_without_node_path_request import GetFootnoteWithoutNodePathRequest
 from asposewordscloud.models.requests.get_form_field_request import GetFormFieldRequest
 from asposewordscloud.models.requests.get_form_fields_request import GetFormFieldsRequest
-from asposewordscloud.models.requests.get_form_fields_without_node_path_request import GetFormFieldsWithoutNodePathRequest
-from asposewordscloud.models.requests.get_form_field_without_node_path_request import GetFormFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.get_header_footer_request import GetHeaderFooterRequest
 from asposewordscloud.models.requests.get_header_footer_of_section_request import GetHeaderFooterOfSectionRequest
 from asposewordscloud.models.requests.get_header_footers_request import GetHeaderFootersRequest
@@ -97,18 +76,11 @@ from asposewordscloud.models.requests.get_list_request import GetListRequest
 from asposewordscloud.models.requests.get_lists_request import GetListsRequest
 from asposewordscloud.models.requests.get_office_math_object_request import GetOfficeMathObjectRequest
 from asposewordscloud.models.requests.get_office_math_objects_request import GetOfficeMathObjectsRequest
-from asposewordscloud.models.requests.get_office_math_objects_without_node_path_request import GetOfficeMathObjectsWithoutNodePathRequest
-from asposewordscloud.models.requests.get_office_math_object_without_node_path_request import GetOfficeMathObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.get_paragraph_request import GetParagraphRequest
 from asposewordscloud.models.requests.get_paragraph_format_request import GetParagraphFormatRequest
-from asposewordscloud.models.requests.get_paragraph_format_without_node_path_request import GetParagraphFormatWithoutNodePathRequest
 from asposewordscloud.models.requests.get_paragraph_list_format_request import GetParagraphListFormatRequest
-from asposewordscloud.models.requests.get_paragraph_list_format_without_node_path_request import GetParagraphListFormatWithoutNodePathRequest
 from asposewordscloud.models.requests.get_paragraphs_request import GetParagraphsRequest
-from asposewordscloud.models.requests.get_paragraphs_without_node_path_request import GetParagraphsWithoutNodePathRequest
 from asposewordscloud.models.requests.get_paragraph_tab_stops_request import GetParagraphTabStopsRequest
-from asposewordscloud.models.requests.get_paragraph_tab_stops_without_node_path_request import GetParagraphTabStopsWithoutNodePathRequest
-from asposewordscloud.models.requests.get_paragraph_without_node_path_request import GetParagraphWithoutNodePathRequest
 from asposewordscloud.models.requests.get_range_text_request import GetRangeTextRequest
 from asposewordscloud.models.requests.get_run_request import GetRunRequest
 from asposewordscloud.models.requests.get_run_font_request import GetRunFontRequest
@@ -123,51 +95,38 @@ from asposewordscloud.models.requests.get_table_request import GetTableRequest
 from asposewordscloud.models.requests.get_table_cell_request import GetTableCellRequest
 from asposewordscloud.models.requests.get_table_cell_format_request import GetTableCellFormatRequest
 from asposewordscloud.models.requests.get_table_properties_request import GetTablePropertiesRequest
-from asposewordscloud.models.requests.get_table_properties_without_node_path_request import GetTablePropertiesWithoutNodePathRequest
 from asposewordscloud.models.requests.get_table_row_request import GetTableRowRequest
 from asposewordscloud.models.requests.get_table_row_format_request import GetTableRowFormatRequest
 from asposewordscloud.models.requests.get_tables_request import GetTablesRequest
-from asposewordscloud.models.requests.get_tables_without_node_path_request import GetTablesWithoutNodePathRequest
-from asposewordscloud.models.requests.get_table_without_node_path_request import GetTableWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_comment_request import InsertCommentRequest
 from asposewordscloud.models.requests.insert_drawing_object_request import InsertDrawingObjectRequest
-from asposewordscloud.models.requests.insert_drawing_object_without_node_path_request import InsertDrawingObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_field_request import InsertFieldRequest
-from asposewordscloud.models.requests.insert_field_without_node_path_request import InsertFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_footnote_request import InsertFootnoteRequest
-from asposewordscloud.models.requests.insert_footnote_without_node_path_request import InsertFootnoteWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_form_field_request import InsertFormFieldRequest
-from asposewordscloud.models.requests.insert_form_field_without_node_path_request import InsertFormFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_header_footer_request import InsertHeaderFooterRequest
 from asposewordscloud.models.requests.insert_list_request import InsertListRequest
 from asposewordscloud.models.requests.insert_or_update_paragraph_tab_stop_request import InsertOrUpdateParagraphTabStopRequest
-from asposewordscloud.models.requests.insert_or_update_paragraph_tab_stop_without_node_path_request import InsertOrUpdateParagraphTabStopWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_page_numbers_request import InsertPageNumbersRequest
 from asposewordscloud.models.requests.insert_paragraph_request import InsertParagraphRequest
-from asposewordscloud.models.requests.insert_paragraph_without_node_path_request import InsertParagraphWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_run_request import InsertRunRequest
 from asposewordscloud.models.requests.insert_style_request import InsertStyleRequest
 from asposewordscloud.models.requests.insert_table_request import InsertTableRequest
 from asposewordscloud.models.requests.insert_table_cell_request import InsertTableCellRequest
 from asposewordscloud.models.requests.insert_table_row_request import InsertTableRowRequest
-from asposewordscloud.models.requests.insert_table_without_node_path_request import InsertTableWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_watermark_image_request import InsertWatermarkImageRequest
 from asposewordscloud.models.requests.insert_watermark_text_request import InsertWatermarkTextRequest
 from asposewordscloud.models.requests.load_web_document_request import LoadWebDocumentRequest
 from asposewordscloud.models.requests.move_file_request import MoveFileRequest
 from asposewordscloud.models.requests.move_folder_request import MoveFolderRequest
+from asposewordscloud.models.requests.optimize_document_request import OptimizeDocumentRequest
 from asposewordscloud.models.requests.protect_document_request import ProtectDocumentRequest
 from asposewordscloud.models.requests.reject_all_revisions_request import RejectAllRevisionsRequest
 from asposewordscloud.models.requests.remove_range_request import RemoveRangeRequest
 from asposewordscloud.models.requests.render_drawing_object_request import RenderDrawingObjectRequest
-from asposewordscloud.models.requests.render_drawing_object_without_node_path_request import RenderDrawingObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.render_math_object_request import RenderMathObjectRequest
-from asposewordscloud.models.requests.render_math_object_without_node_path_request import RenderMathObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.render_page_request import RenderPageRequest
 from asposewordscloud.models.requests.render_paragraph_request import RenderParagraphRequest
-from asposewordscloud.models.requests.render_paragraph_without_node_path_request import RenderParagraphWithoutNodePathRequest
 from asposewordscloud.models.requests.render_table_request import RenderTableRequest
-from asposewordscloud.models.requests.render_table_without_node_path_request import RenderTableWithoutNodePathRequest
 from asposewordscloud.models.requests.replace_text_request import ReplaceTextRequest
 from asposewordscloud.models.requests.replace_with_text_request import ReplaceWithTextRequest
 from asposewordscloud.models.requests.reset_cache_request import ResetCacheRequest
@@ -181,24 +140,19 @@ from asposewordscloud.models.requests.update_bookmark_request import UpdateBookm
 from asposewordscloud.models.requests.update_border_request import UpdateBorderRequest
 from asposewordscloud.models.requests.update_comment_request import UpdateCommentRequest
 from asposewordscloud.models.requests.update_drawing_object_request import UpdateDrawingObjectRequest
-from asposewordscloud.models.requests.update_drawing_object_without_node_path_request import UpdateDrawingObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.update_field_request import UpdateFieldRequest
 from asposewordscloud.models.requests.update_fields_request import UpdateFieldsRequest
 from asposewordscloud.models.requests.update_footnote_request import UpdateFootnoteRequest
-from asposewordscloud.models.requests.update_footnote_without_node_path_request import UpdateFootnoteWithoutNodePathRequest
 from asposewordscloud.models.requests.update_form_field_request import UpdateFormFieldRequest
-from asposewordscloud.models.requests.update_form_field_without_node_path_request import UpdateFormFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.update_list_request import UpdateListRequest
 from asposewordscloud.models.requests.update_list_level_request import UpdateListLevelRequest
 from asposewordscloud.models.requests.update_paragraph_format_request import UpdateParagraphFormatRequest
 from asposewordscloud.models.requests.update_paragraph_list_format_request import UpdateParagraphListFormatRequest
-from asposewordscloud.models.requests.update_paragraph_list_format_without_node_path_request import UpdateParagraphListFormatWithoutNodePathRequest
 from asposewordscloud.models.requests.update_run_request import UpdateRunRequest
 from asposewordscloud.models.requests.update_run_font_request import UpdateRunFontRequest
 from asposewordscloud.models.requests.update_section_page_setup_request import UpdateSectionPageSetupRequest
 from asposewordscloud.models.requests.update_style_request import UpdateStyleRequest
 from asposewordscloud.models.requests.update_table_cell_format_request import UpdateTableCellFormatRequest
 from asposewordscloud.models.requests.update_table_properties_request import UpdateTablePropertiesRequest
-from asposewordscloud.models.requests.update_table_properties_without_node_path_request import UpdateTablePropertiesWithoutNodePathRequest
 from asposewordscloud.models.requests.update_table_row_format_request import UpdateTableRowFormatRequest
 from asposewordscloud.models.requests.upload_file_request import UploadFileRequest
