@@ -29,18 +29,18 @@ class GetBorderRequest(object):
     Request model for get_border operation.
     Initializes a new instance.
     :param name The document name.
-    :param node_path Path to the node with border(node should be paragraph, cell or row).
     :param border_type Border type.
+    :param node_path Path to the node with border(node should be paragraph, cell or row).
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
     :param password Password for opening an encrypted document.
     """
 
-    def __init__(self, name, node_path, border_type, folder=None, storage=None, load_encoding=None, password=None):
+    def __init__(self, name, border_type, node_path=None, folder=None, storage=None, load_encoding=None, password=None):
         self.name = name
-        self.node_path = node_path
         self.border_type = border_type
+        self.node_path = node_path
         self.folder = folder
         self.storage = storage
         self.load_encoding = load_encoding
